#include "Sphere.h"

/* Constructor, just calls the generator */
Sphere::Sphere()
{
  xpos = ypos = zpos = 0;
  colorR = colorG = colorB = 1;
  generate();
}

/* Constructor that accepts an initial location
 * as parameters.
 */
Sphere::Sphere(GLfloat x, GLfloat y, GLfloat z)
{
  xpos = x;
  ypos = y;
  zpos = z;
  colorR = colorG = colorB = 1;
  generate();
}

/* Constructor that accepts initial location and
 * color as parameters.
 */
Sphere::Sphere(GLfloat x, GLfloat y, GLfloat z, GLfloat r, GLfloat g, GLfloat b)
{
  xpos = x;
  ypos = y;
  zpos = z;
  colorR = r;
  colorG = g;
  colorB = b;
  generate();
}

Sphere::~Sphere()
{}

// Draws the sphere and stores it into a call list.
void Sphere::generate()
{
  // Create the sphere objects we need.
  GLUquadricObj *quadric;
  quadric = gluNewQuadric();

  // Start recording the call list.
  sphere = glGenLists(1);
  glNewList(sphere,GL_COMPILE);

  // Set the lighting values
  glPushMatrix();
  float white[] = {1,1,1,1};
  float black[] = {0,0,0,1};
  float shinyvec[] = {0};
  glMaterialfv(GL_FRONT_AND_BACK,GL_SHININESS,shinyvec);
  glMaterialfv(GL_FRONT_AND_BACK,GL_SPECULAR,white);
  glMaterialfv(GL_FRONT_AND_BACK,GL_EMISSION,black);
  
  // Draw the sphere
  gluQuadricDrawStyle(quadric, GLU_FILL );
  gluSphere(quadric,0.4,10,10);
  glPopMatrix();

  // Stop recording and delete the quadric object.
  glEndList();
  gluDeleteQuadric(quadric); 
}


// Locate and draw the sphere.
void Sphere::draw()
{
  glPushMatrix();
  glTranslated(xpos, ypos, zpos);
  glColor3f(colorR, colorG, colorB);
  glCallList(sphere);
  glPopMatrix();
}

// Set the position of the sphere.
void Sphere::setPos(GLfloat x, GLfloat y, GLfloat z)
{
  xpos = x;
  ypos = y;
  zpos = z;
}
  
// Set the color of the sphere.
void Sphere::setColor(GLfloat r, GLfloat g, GLfloat b)
{
  colorR = r;
  colorG = g;
  colorB = b;
}